@@ -55,7 +55,7 @@ class SmdaReport(object):
             self.status = disassembly.getAnalysisOutcome()
             if self.status == "timeout":
                 self.message = "Analysis was stopped when running into the timeout."
-            self.timestamp = datetime.datetime.utcnow().strftime("%Y-%m-%dT%H-%M-%S")
+            self.timestamp = datetime.datetime.utcnow()
             self.version = disassembly.binary_info.version
             self.xcfg = self._convertCfg(disassembly, config=config)
 
